import React from 'react';
import { useQuery, useQueryClient, useMutation } from '@tanstack/react-query';

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}

function configureAuth(config) {
  var userFn = config.userFn,
    _config$userKey = config.userKey,
    userKey = _config$userKey === void 0 ? ['authenticated-user'] : _config$userKey,
    loginFn = config.loginFn,
    registerFn = config.registerFn,
    logoutFn = config.logoutFn;
  var useUser = function useUser(options) {
    return useQuery(userKey, userFn, options);
  };
  var useLogin = function useLogin(options) {
    var queryClient = useQueryClient();
    var setUser = React.useCallback(function (data) {
      return queryClient.setQueryData(userKey, data);
    }, [queryClient]);
    return useMutation(_extends({
      mutationFn: loginFn
    }, options, {
      onSuccess: function onSuccess(user) {
        setUser(user);
        for (var _len = arguments.length, rest = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
          rest[_key - 1] = arguments[_key];
        }
        options == null ? void 0 : options.onSuccess == null ? void 0 : options.onSuccess.apply(options, [user].concat(rest));
      }
    }));
  };
  var useRegister = function useRegister(options) {
    var queryClient = useQueryClient();
    var setUser = React.useCallback(function (data) {
      return queryClient.setQueryData(userKey, data);
    }, [queryClient]);
    return useMutation(_extends({
      mutationFn: registerFn
    }, options, {
      onSuccess: function onSuccess(user) {
        setUser(user);
        for (var _len2 = arguments.length, rest = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
          rest[_key2 - 1] = arguments[_key2];
        }
        options == null ? void 0 : options.onSuccess == null ? void 0 : options.onSuccess.apply(options, [user].concat(rest));
      }
    }));
  };
  var useLogout = function useLogout(options) {
    var queryClient = useQueryClient();
    var setUser = React.useCallback(function (data) {
      return queryClient.setQueryData(userKey, data);
    }, [queryClient]);
    return useMutation(_extends({
      mutationFn: logoutFn
    }, options, {
      onSuccess: function onSuccess() {
        setUser(null);
        for (var _len3 = arguments.length, args = new Array(_len3), _key3 = 0; _key3 < _len3; _key3++) {
          args[_key3] = arguments[_key3];
        }
        options == null ? void 0 : options.onSuccess == null ? void 0 : options.onSuccess.apply(options, args);
      }
    }));
  };
  function AuthLoader(_ref) {
    var children = _ref.children,
      renderLoading = _ref.renderLoading,
      renderUnauthenticated = _ref.renderUnauthenticated;
    var _useUser = useUser(),
      isSuccess = _useUser.isSuccess,
      isFetched = _useUser.isFetched,
      status = _useUser.status,
      data = _useUser.data;
    if (isSuccess) {
      if (renderUnauthenticated && !data) {
        return renderUnauthenticated();
      }
      return React.createElement(React.Fragment, null, children);
    }
    if (!isFetched) {
      return renderLoading();
    }
    return React.createElement("div", null, "Unhandled status: ", status);
  }
  return {
    useUser: useUser,
    useLogin: useLogin,
    useRegister: useRegister,
    useLogout: useLogout,
    AuthLoader: AuthLoader
  };
}

export { configureAuth };
//# sourceMappingURL=react-query-auth.esm.js.map
